/*
 * Copyright (C) 2010 Company 100, Inc. All rights reserved.
 * Copyright (c) 2012 NINTENDO.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebSocketStreamHandlePrivate_h
#define WebSocketStreamHandlePrivate_h

#include "SocketStreamHandleBase.h"
#include "Timer.h"
#include <wtf/OwnPtr.h>

#if PLATFORM(WIIU) && defined(ENABLE_HIO_INSPECTOR)
#include <PlatformDebugIO.h>
#include <PlatformDefines.h>
using namespace LibPlatform;
#endif

namespace WebCore {

class SocketStreamHandleClient;
class WebSocketStreamHandlePrivate;
class TcpSocketWiiU; 

class TcpSocketWiiU {
public:
    TcpSocketWiiU(WebSocketStreamHandlePrivate * handle );
    virtual ~TcpSocketWiiU();
private:
	TcpSocketWiiU();

	Timer <TcpSocketWiiU> m_receiveTimer;
	void notificationReceiveTimerFired(Timer<TcpSocketWiiU>*);
	WebSocketStreamHandlePrivate * m_handle; //Make a list;

};

class WebSocketStreamHandlePrivate : public TcpSocketWiiU {
public:
    WebSocketStreamHandlePrivate(WebSocketStreamHandle*, int);
    ~WebSocketStreamHandlePrivate();

    #if PLATFORM(WIIU) && defined(ENABLE_HIO_INSPECTOR)
    WebSocketStreamHandlePrivate(WebSocketStreamHandle*, int, bool);
    #endif

    void socketConnected();
    bool isConnected();
    bool isClosed();
    int socketReadyRead();
    void socketClosed();
    void socketError(int);

    int socketSend(const char* data, int len);
    void socketClose();

    int m_socketFd;

    #if PLATFORM(WIIU) && defined(ENABLE_HIO_INSPECTOR)
    DebugIO::Handle m_hioHandle;
    static bool m_hioConnected;
    static WTF::Mutex m_hioConnectedMutex;
    #endif

    enum  {
        RCVBUFSIZE = 8182
    };
    char m_rcvBuffer[RCVBUFSIZE]; 

    WebSocketStreamHandle* m_streamHandle;
};
}

#endif // SocketStreamHandlePrivate_h
