/*
 * Copyright (c) 2012 NINTENDO.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions, and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions, and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY NINTENDO AND ITS CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL NINTENDO OR CONTRIBUTORS BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WiiUEventManager_h
#define WiiUEventManager_h

#include <config.h>
#include <wtf/MessageQueue.h>
#if OS(WINDOWS)
#include <libshim/include/pthread.h>
#else
#include <pthread.h>
#endif

#include "WiiUEvent.h"

/*
 * Base class for wiiu event data.
 */
class WiiUBaseEventData;

namespace WebCore {

/*
 * This is the data type that is added to the event queue.
 */
//Fixme: class WiiUEvent;

/*
 * This is the event manager for webkit.  It is brain that drives the browser.
 */
class WiiUEventManager {
public:
	WiiUEventManager();
	~WiiUEventManager();
	static WiiUEventManager *instance();
	static void destroy();
	void waitEvent(WiiUBaseEventData **data);
	bool waitEventWithTimeout(WiiUBaseEventData **data, double timeoutSeconds);
	void putEvent(WiiUBaseEventData* data);
	int getNextEvent(WiiUBaseEventData **data);

private:
	MessageQueue<WiiUEvent>		m_eventQueue;		//!< Event queue
	pthread_mutex_t				m_queueMutex;		//!< Mutex to ensure save state changes reg. exclusive events

	static WiiUEventManager	*	m_instance;			//!< Singleton instance pointer
};

}
#endif
