/*
 * Copyright (c) 2012 NINTENDO.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions, and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions, and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY NINTENDO AND ITS CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL NINTENDO OR CONTRIBUTORS BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef ERROR_CODES_H
#define ERROR_CODES_H

	enum ErrorCategory {
		ERROR_CATEGORY_CMN_MSG = 199,
		ERROR_CATEGORY_FP = 101,
		ERROR_CATEGORY_ACT = 102,
		ERROR_CATEGORY_AC = 103,
		ERROR_CATEGORY_FS = 150,
		ERROR_CATEGORY_KPAD = 151,
		ERROR_CATEGORY_WPAD = 152,
		ERROR_CATEGORY_SAVE = 155,
		ERROR_CATEGORY_UDS = 156,
		ERROR_CATEGORY_ACP = 157,
		ERROR_CATEGORY_SSI = 158,
		ERROR_CATEGORY_VPAD = 165,
	};

	/**
	When system errors are reported they declare a type.
	The error will be handled differently depending on its type.
	*/
	enum ErrorCode {
		UNKNOWN = 0,
		ERROR_CODE_WPAD_ERR_NO_CONTROLLER = 1520100,
		ERROR_CODE_WPAD_ERR_BUSY = 1520101,
		ERROR_CODE_WPAD_ERR_TRANSFER = 1520102,
		ERROR_CODE_WPAD_ERR_INVALID = 1520103,
		ERROR_CODE_WPAD_ERR_NOPERM = 1520104,
		ERROR_CODE_WPAD_ERR_BROKEN = 1520105,
		ERROR_CODE_WPAD_ERR_CORRUPTED = 1520106,
		ERROR_CODE_KPAD_READ_ERR_NO_DATA = 1510100,
		ERROR_CODE_KPAD_READ_ERR_NO_CONTROLLER = 1510101,
		ERROR_CODE_KPAD_READ_ERR_SETUP = 1510102,
		ERROR_CODE_KPAD_READ_ERR_LOCKED = 1510103,
		ERROR_CODE_KPAD_READ_ERR_INIT = 1510104,
		ERROR_CODE_KPAD_WBC_ERR_NO_BATTERY = 1510201,
		ERROR_CODE_KPAD_WBC_ERR_SETUP = 1510202,
		ERROR_CODE_KPAD_WBC_ERR_WRONG_ZERO = 1510203,
		ERROR_CODE_KPAD_WBC_ERR_WEIGHT_OVER = 1510204,
		ERROR_CODE_KPAD_WBC_ERR_CALIBRATION = 1510205,
		ERROR_CODE_KPAD_WBC_ERR_NO_ZEROPOINT = 1510206,
		ERROR_CODE_FS_VOLSTATE_INITIAL = 1501000,
		ERROR_CODE_FS_VOLSTATE_NO_MEDIA = 1501011,
		ERROR_CODE_FS_STATUS_MEDIA_NOT_READY = 1501014,
		ERROR_CODE_FS_VOLSTATE_INVALID_MEDIA = 1501021,
		ERROR_CODE_FS_STATUS_INVALID_MEDIA = 1501024,
		ERROR_CODE_FS_VOLSTATE_DIRTY_MEDIA = 1501031,
		ERROR_CODE_FS_VOLSTATE_MEDIA_ERROR = 1501042,
		ERROR_CODE_FS_STATUS_MEDIA_ERROR = 1501044,
		ERROR_CODE_FS_VOLSTATE_DATA_CORRUPTED = 1501051,
		ERROR_CODE_FS_STATUS_DATA_CORRUPTED = 1501054,
		ERROR_CODE_FS_VOLSTATE_WRITE_PROTECTED = 1501063,
		ERROR_CODE_FS_STATUS_WRITE_PROTECTED = 1501064,
		ERROR_CODE_FS_VOLSTATE_WRONG_MEDIA = 1501071,
		ERROR_CODE_FS_VOLSTATE_JOURNAL_FULL = 1501082,
		ERROR_CODE_FS_STATUS_FATAL_ERROR = 1501090,
		ERROR_CODE_CMN_MSG_FATAL = 1999999,
		ERROR_CODE_CMN_MSG_JUMP_SETTING_TOP = 1990010,
		ERROR_CODE_CMN_MSG_JUMP_SETTING_INTERNET = 1990011,
		ERROR_CODE_CMN_MSG_JUMP_SETTING_DATA_MANAGE = 1990012,
		ERROR_CODE_CMN_MSG_JUMP_SETTING_DATE_TIME = 1990014,
		ERROR_CODE_CMN_MSG_JUMP_SETTING_COUNTRY = 1990015,
		ERROR_CODE_CMN_MSG_JUMP_SETTING_UPDATE = 1990016,
		ERROR_CODE_CMN_MSG_JUMP_ACCOUNT_SETTING = 1990020,
		ERROR_CODE_CMN_MSG_JUMP_ACCOUNT_SETTING_2 = 1990021,
		ERROR_CODE_CMN_MSG_JUMP_APP_REBOOT = 1990030,
		ERROR_CODE_CMN_MSG_REREASE_PARENTAL_CONTROLL = 1990040,
		ERROR_CODE_CMN_MSG_NGWORD_NOT_ACCEPTABLE = 1990101,
		ERROR_CODE_CMN_MSG_NGWORD_ACCEPTABLE = 1990102,
		ERROR_CODE_CMN_MSG_TEXT_OVER_LIMIT = 1990105,
		ERROR_CODE_CMN_MSG_TEXT_NO_INPUT = 1990106,
		ERROR_CODE_CMN_MSG_NUMBER_NOT_ACCEPTABLE = 1990110,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_1 = 1990111,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_2 = 1990112,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_3 = 1990113,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_4 = 1990114,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_5 = 1990115,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_6 = 1990116,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_7 = 1990117,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_8 = 1990118,
		ERROR_CODE_CMN_MSG_NUMBER_OVER_LIMIT_9 = 1990119,
		ERROR_CODE_CMN_MSG_NOT_MATCH_PASSWORD = 1990120,
		ERROR_CODE_CMN_MSG_NOT_MATCH_EMAIL = 1990121,
		ERROR_CODE_CMN_MSG_WORNG_PASSWORD = 1990131,
		ERROR_CODE_CMN_MSG_WORNG_PIN_CODE = 1990132,
		ERROR_CODE_CMN_MSG_WORNG_FRIEND_CODE = 1990133,
		ERROR_CODE_CMN_MSG_WORNG_NNID = 1990134,
		ERROR_CODE_CMN_MSG_WORNG_INPUT = 1990135,
		ERROR_CODE_CMN_MSG_WIIEMAIL_NOT_ACCEPTABLE = 1990136,
		ERROR_CODE_CMN_MSG_FORGET_PIN_CODE = 1990140,
		ERROR_CODE_CMN_MSG_SWKBD_FATAL = 1990199,
		ERROR_CODE_CMN_MSG_NEED_WII_REMOTE = 1990200,
		ERROR_CODE_CMN_MSG_NEED_WII_NUNCHAK = 1990201,
		ERROR_CODE_CMN_MSG_NEED_WII_REMOTE_PLUS = 1990202,
		ERROR_CODE_CMN_MSG_NEED_WII_U_PRO_CONTROLLER = 1990203,
		ERROR_CODE_CMN_MSG_NEED_WII_BALANCE_BOARD = 1990204,
		ERROR_CODE_CMN_MSG_NEED_WII_CLASSIC_CONTROLLER = 1990205,
		ERROR_CODE_CMN_MSG_NEED_WII_U_GAMEPAD = 1990210,
		ERROR_CODE_CMN_MSG_WII_REMOTE__NO_BATTERY = 1990301,
		ERROR_CODE_CMN_MSG_WII_U_GAMEPAD_NO_BATTERY = 1990302,
		ERROR_CODE_CMN_MSG_WII_U_PRO_CONTROLLER_NO_BATTERY = 1990303,
		ERROR_CODE_CMN_MSG_WII_BALANCE_BOARD_NO_BATTERY = 1990304,
		ERROR_CODE_CMN_MSG_MII_ALREADY_SAVED = 1990401,
		ERROR_CODE_CMN_MSG_MII_CANT_SAVE = 1990402,
		ERROR_CODE_CMN_MSG_MII_OVER_WRITE_CONFIRM = 1990403,
		ERROR_CODE_CMN_MSG_MII_NO_SPACE = 1990404,
		ERROR_CODE_CMN_MSG_FUNCTION_PROTECTED = 1990501,
		ERROR_CODE_CMN_MSG_NETWORK_FUNCTION_PROTECTED = 1990502,
		ERROR_CODE_CMN_MSG_INTERNET_BROWSER_PROTECTED = 1990503,
		ERROR_CODE_CMN_MSG_PROTECTION_RELEASED = 1990510,
		ERROR_CODE_SAVE_STATUS_STORAGE_FULL = 1550100,
		ERROR_CODE_FS_STATUS_NOT_FOUND = 1550101,
		ERROR_CODE_FS_STATUS_JOURNAL_FULL = 1550102,
		ERROR_CODE_ACP_STATUS_DEVICE_FULL = 1550200,
		ERROR_CODE_ACP_STATUS_UNSUPPORTED = 1550201,
		ERROR_CODE_ACP_STATUS_DEVICE_NOT_FOUND = 1550202,
		ERROR_CODE_ACP_STATUS_ACCOUNT_ERROR = 1550203,
		ERROR_CODE_ACP_STATUS_RESOURCE_ERROR = 1550204,
		ERROR_CODE_ACP_STATUS_MEDIA_NOTREADY = 1550205,
		ERROR_CODE_ACP_STATUS_TITLE_NOT_FOUND = 1550206,
		ERROR_CODE_ACP_STATUS_DIR_NOT_FOUND = 1550207,
		ERROR_CODE_ACP_STATUS_FILE_NOT_FOUND = 1550208,
		ERROR_CODE_ACP_STATUS_INVALID_XML_FILE = 1550209,
		ERROR_CODE_ACP_STATUS_XML_ITEM_NOT_FOUND = 1550210,
		ERROR_CODE_ACP_STATUS_PERMISSION_ERROR = 1550211,
		ERROR_CODE_ACP_STATUS_SYSTEM_MEMORY = 1550212,
		ERROR_CODE_ACP_STATUS_INVALID_PARAM = 1570100,
		ERROR_CODE_ACP_STATUS_NOT_FOUND = 1570101,
		ERROR_CODE_ACP_STATUS_INVALID_LOGO = 1570103,
		ERROR_CODE_ACP_STATUS_INVALID_REGION = 1570104,
		ERROR_CODE_ACP_STATUS_RESTRICTED_RATING  = 1570105,
		ERROR_CODE_ACP_STATUS_NOTPRESENT_RATING = 1570106,
		ERROR_CODE_ACP_STATUS_PENDING_RATING = 1570107,
		ERROR_CODE_ACP_STATUS_BROWSER_REQUIRED = 1570108,
		ERROR_CODE_ACP_STATUS_OLV_REQUIRED = 1570109,
		ERROR_CODE_ACP_STATUS_NETSETTING_REQUIRED = 1570111,
		ERROR_CODE_ACP_STATUS_NETACCOUNT_REQUIRED = 1570112,
		ERROR_CODE_ACP_STATUS_NETACCOUNT_ERROR = 1570113,
		ERROR_CODE_ACP_STATUS_INCORRECT_PINCODE = 1570114,
		ERROR_CODE_ACP_STATUS_GamePad_REQUIRED = 1570115,
		ERROR_CODE_VPAD_READ_ERR_NO_CONTROLLER = 1650101,
		ERROR_CODE_CORE_UNKNOWN = 1010102,
		ERROR_CODE_CORE_NOT_IMPLEMENTED = 1010103,
		ERROR_CODE_CORE_INVALID_POINTER = 1010104,
		ERROR_CODE_CORE_OPERATION_ABORTED = 1010105,
		ERROR_CODE_CORE_EXCEPTION = 1010106,
		ERROR_CODE_CORE_ACCESS_DENIED = 1010107,
		ERROR_CODE_CORE_INVALID_HANDLE = 1010108,
		ERROR_CODE_CORE_INVALID_INDEX = 1010109,
		ERROR_CODE_CORE_OUT_OF_MEMORY = 1010110,
		ERROR_CODE_CORE_INVALID_ARGUMENT = 1010111,
		ERROR_CODE_CORE_TIMEOUT = 1010112,
		ERROR_CODE_CORE_INITIALIZATION_FAILURE = 1010113,
		ERROR_CODE_CORE_CALL_INITIATION_FAILURE = 1010114,
		ERROR_CODE_CORE_REGISTRATION_ERROR = 1010115,
		ERROR_CODE_CORE_BUFFER_OVERFLOW = 1010116,
		ERROR_CODE_CORE_INVALID_LOCK_STATE = 1010117,
		ERROR_CODE_DDL_INVALID_SIGNATURE = 1010201,
		ERROR_CODE_DDL_INCORRECT_VERSION = 1010202,
		ERROR_CODE_RENDEZVOUS_CONNECTION_FAILURE = 1010301,
		ERROR_CODE_RENDEZVOUS_NOT_AUTHENTICATED = 1010302,
		ERROR_CODE_RENDEZVOUS_INVALID_USERNAME = 1010303,
		ERROR_CODE_RENDEZVOUS_INVALID_PASSWORD = 1010304,
		ERROR_CODE_RENDEZVOUS_USERNAME_ALREADY_EXISTS = 1010305,
		ERROR_CODE_RENDEZVOUS_ACCOUNT_DISABLED = 1010306,
		ERROR_CODE_RENDEZVOUS_ACCOUNT_EXPIRED = 1010307,
		ERROR_CODE_RENDEZVOUS_CONCURRENT_LOGIN_DENIED = 1010308,
		ERROR_CODE_RENDEZVOUS_ENCRYPTION_FAILURE = 1010309,
		ERROR_CODE_RENDEZVOUS_INVALID_PID = 1010310,
		ERROR_CODE_RENDEZVOUS_MAX_CONNECTIONS_REACHED = 1010311,
		ERROR_CODE_RENDEZVOUS_INVALID_GID = 1010312,
		ERROR_CODE_RENDEZVOUS_INVALID_THREAD_ID = 1010313,
		ERROR_CODE_RENDEZVOUS_INVALID_OPERATION_IN_LIVE_ENVIRONMENT = 1010314,
		ERROR_CODE_RENDEZVOUS_DUPLICATE_ENTRY = 1010315,
		ERROR_CODE_RENDEZVOUS_CONTROL_SCRIPT_FAILURE = 1010316,
		ERROR_CODE_RENDEZVOUS_CLASS_NOT_FOUND = 1010317,
		ERROR_CODE_RENDEZVOUS_DDL_MISMATCH = 1010320,
		ERROR_CODE_PYTHONCORE_EXCEPTION = 1010401,
		ERROR_CODE_PYTHONCORE_TYPE_ERROR = 1010402,
		ERROR_CODE_PYTHONCORE_INDEX_ERROR = 1010403,
		ERROR_CODE_PYTHONCORE_INVALID_REFERENCE = 1010404,
		ERROR_CODE_PYTHONCORE_CALL_FAILURE = 1010405,
		ERROR_CODE_PYTHONCORE_MEMORY_ERROR = 1010406,
		ERROR_CODE_PYTHONCORE_KEY_ERROR = 1010407,
		ERROR_CODE_PYTHONCORE_OPERATION_ERROR = 1010408,
		ERROR_CODE_PYTHONCORE_CONVERSION_ERROR = 1010409,
		ERROR_CODE_PYTHONCORE_VALIDATION_ERROR = 1010410,
		ERROR_CODE_TRANSPORT_UNKNOWN = 1010501,
		ERROR_CODE_TRANSPORT_CONNECTION_FAILURE = 1010502,
		ERROR_CODE_TRANSPORT_INVALID_URL = 1010503,
		ERROR_CODE_TRANSPORT_INVALID_KEY = 1010504,
		ERROR_CODE_TRANSPORT_INVALID_URL_TYPE = 1010505,
		ERROR_CODE_TRANSPORT_DUPLICATE_ENDPOINT = 1010506,
		ERROR_CODE_TRANSPORT_IO_ERROR = 1010507,
		ERROR_CODE_TRANSPORT_TIMEOUT = 1010508,
		ERROR_CODE_TRANSPORT_CONNECTION_RESET = 1010509,
		ERROR_CODE_TRANSPORT_INCORRECT_REMOTE_AUTHENTICATION = 1010510,
		ERROR_CODE_TRANSPORT_SERVER_REQUEST_ERROR = 1010511,
		ERROR_CODE_TRANSPORT_DECOMPRESSION_FAILURE = 1010512,
		ERROR_CODE_TRANSPORT_CONGESTED_END_POINT = 1010513,
		ERROR_CODE_TRANSPORT_SOCKET_SEND_WARNING = 1010518,
		ERROR_CODE_TRANSPORT_UNSUPPORTED_NAT = 1010519,
		ERROR_CODE_TRANSPORT_DNS_ERROR = 1010520,
		ERROR_CODE_TRANSPORT_PROXY_ERROR = 1010521,
		ERROR_CODE_TRANSPORT_DATA_REMAINING = 1010522,
		ERROR_CODE_TRANSPORT_NO_BUFFER = 1010523,
		ERROR_CODE_TRANSPORT_NOT_FOUND = 1010524,
		ERROR_CODE_DAEMON_NOT_INITIALIZED = 1010702,
		ERROR_CODE_DAEMON_ALREADY_INITIALIZED = 1010703,
		ERROR_CODE_NOT_CONNECTED = 1010704,
		ERROR_CODE_CONNECTED = 1010705,
		ERROR_CODE_INITIALIZATION_FAILURE = 1010706,
		ERROR_CODE_OUT_OF_MEMORY = 1010707,
		ERROR_CODE_RMC_FAILED = 1010708,
		ERROR_CODE_INVALID_ARGUMENT = 1010709,
		ERROR_CODE_FPD_INVALID_PRINCIPAL_ID = 1010711,
		ERROR_CODE_FILE_IO_ERROR = 1010720,
		ERROR_CODE_FPD_UNKNOWN = 1010722,
		ERROR_CODE_FPD_INVALID_STATE = 1010723,
		ERROR_CODE_FPD_ADD_FRIEND_PROHIBITED = 1010725,
		ERROR_CODE_FPD_INVALID_ACCOUNT = 1010727,
		ERROR_CODE_FPD_BLACKLISTED_BY_ME = 1010728,
		ERROR_CODE_FPD_FRIEND_ALREADY_ADDED = 1010730,
		ERROR_CODE_FPD_MY_FRIEND_LIST_LIMIT_EXCEED = 1010731,
		ERROR_CODE_FPD_REQUEST_LIMIT_EXCEED = 1010732,
		ERROR_CODE_FPD_INVALID_MESSAGE_ID = 1010733,
		ERROR_CODE_FPD_MESSAGE_IS_NOT_MINE = 1010734,
		ERROR_CODE_FPD_MESSAGE_IS_NOT_FOR_ME = 1010735,
		ERROR_CODE_FPD_FRIEND_REQUEST_BLOCKED = 1010736,
		ERROR_CODE_FPD_NOT_IN_MY_FRIEND_LIST = 1010737,
		ERROR_CODE_FPD_FRIEND_LISTED_BY_ME = 1010738,
		ERROR_CODE_FPD_NOT_IN_MY_BLACKLIST = 1010739,
		ERROR_CODE_FPD_INCOMPATIBLE_ACCOUNT = 1010740,
		ERROR_CODE_FPD_BLOCK_SETTING_CHANGE_NOT_ALLOWED = 1010741,
		ERROR_CODE_FPD_SIZE_LIMIT_EXCEEDED = 1010742,
		ERROR_CODE_FPD_OPERATION_NOT_ALLOWED = 1010743,
		ERROR_CODE_FPD_NOT_NETWORK_ACCOUNT = 1010744,
		ERROR_CODE_FPD_NOTIFICATION_NOT_FOUND = 1010745,
		ERROR_CODE_AUTHENTICATION_TOKEN_PARSE_ERROR = 1010802,
		ERROR_CODE_AUTHENTICATION_HTTP_CONNECTION_ERROR = 1010803,
		ERROR_CODE_AUTHENTICATION_HTTP_DNS_ERROR = 1010804,
		ERROR_CODE_AUTHENTICATION_HTTP_GET_PROXY_SETTING = 1010805,
		ERROR_CODE_AUTHENTICATION_TOKEN_EXPIRED = 1010806,
		ERROR_CODE_AUTHENTICATION_VALIDATION_FAILED = 1010807,
		ERROR_CODE_AUTHENTICATION_INVALID_PARAM = 1010808,
		ERROR_CODE_AUTHENTICATION_PRINCIPAL_ID_UNMATCHED = 1010809,
		ERROR_CODE_AUTHENTICATION_MOVE_COUNT_UNMATCH = 1010810,
		ERROR_CODE_AUTHENTICATION_UNDER_MAINTENANCE = 1010811,
		ERROR_CODE_AUTHENTICATION_UNSUPPORTED_VERSION = 1010812,
		ERROR_CODE_AUTHENTICATION_UNKNOWN = 1010813,
		ERROR_CODE_DESCRIPTION_NOT_FOUND_ACCESS_POINT = 1031000,
		ERROR_CODE_DESCRIPTION_FAILED_CONNECT_AP = 1031100,
		ERROR_CODE_DESCRIPTION_CONFLICT_IP_ADDRESS = 1031200,
		ERROR_CODE_DESCRIPTION_INVALID = 1034100,
		ERROR_CODE_DESCRIPTION_FAILED_FILE_ACCESS = 1035000,
		ERROR_CODE_ACCOUNT_NOT_FOUND = 1021001,
		ERROR_CODE_SLOTS_FULL = 1021002,
		ERROR_CODE_ACCOUNT_NOT_LOADED = 1021011,
		ERROR_CODE_ACCOUNT_ALREADY_LOADED = 1021012,
		ERROR_CODE_ACCOUNT_LOCKED = 1021013,
		ERROR_CODE_NOT_NETWORK_ACCOUNT = 1021021,
		ERROR_CODE_NOT_LOCAL_ACCOUNT = 1021022,
		ERROR_CODE_ACCOUNT_NOT_COMMITTED = 1021023,
		ERROR_CODE_NETWORK_CLOCK_INVALID = 1021101,
		ERROR_CODE_HTTP_UNSUPPORTED_PROTOCOL = 1022101,
		ERROR_CODE_HTTP_FAILED_INIT = 1022102,
		ERROR_CODE_HTTP_URL_MALFORMAT = 1022103,
		ERROR_CODE_HTTP_NOT_BUILT_IN = 1022104,
		ERROR_CODE_HTTP_COULDNT_RESOLVE_PROXY = 1022105,
		ERROR_CODE_HTTP_COULDNT_RESOLVE_HOST = 1022106,
		ERROR_CODE_HTTP_COULDNT_CONNECT = 1022107,
		ERROR_CODE_HTTP_REMOTE_ACCESS_DENIED = 1022109,
		ERROR_CODE_HTTP_PARTIAL_FILE = 1022118,
		ERROR_CODE_HTTP_QUOTE_ERROR = 1022121,
		ERROR_CODE_HTTP_HTTP_RETURNED_ERROR = 1022122,
		ERROR_CODE_HTTP_WRITE_ERROR = 1022123,
		ERROR_CODE_HTTP_UPLOAD_FAILED = 1022125,
		ERROR_CODE_HTTP_READ_ERROR = 1022126,
		ERROR_CODE_HTTP_OUT_OF_MEMORY = 1022127,
		ERROR_CODE_HTTP_OPERATION_TIMEDOUT = 1022128,
		ERROR_CODE_HTTP_RANGE_ERROR = 1022133,
		ERROR_CODE_HTTP_HTTP_POST_ERROR = 1022134,
		ERROR_CODE_HTTP_SSL_CONNECT_ERROR = 1022135,
		ERROR_CODE_HTTP_BAD_DOWNLOAD_RESUME = 1022136,
		ERROR_CODE_HTTP_FILE_COULDNT_READ_FILE = 1022137,
		ERROR_CODE_HTTP_FUNCTION_NOT_FOUND = 1022141,
		ERROR_CODE_HTTP_ABORTED_BY_CALLBACK = 1022142,
		ERROR_CODE_HTTP_BAD_FUNCTION_ARGUMEN = 1022143,
		ERROR_CODE_HTTP_INTERFACE_FAILED = 1022145,
		ERROR_CODE_HTTP_TOO_MANY_REDIRECTS = 1022147,
		ERROR_CODE_HTTP_UNKNOWN_OPTION = 1022148,
		ERROR_CODE_HTTP_PEER_FAILED_VERIFICATION = 1022151,
		ERROR_CODE_HTTP_GOT_NOTHING = 1022152,
		ERROR_CODE_HTTP_SSL_ENGINE_NOTFOUND = 1022153,
		ERROR_CODE_HTTP_SSL_ENGINE_SETFAILED = 1022154,
		ERROR_CODE_HTTP_SEND_ERROR = 1022155,
		ERROR_CODE_HTTP_RECV_ERROR = 1022156,
		ERROR_CODE_HTTP_SSL_CERTPROBLEM = 1022158,
		ERROR_CODE_HTTP_SSL_CIPHER = 1022159,
		ERROR_CODE_HTTP_SSL_CACERT = 1022160,
		ERROR_CODE_HTTP_BAD_CONTENT_ENCODING = 1022161,
		ERROR_CODE_HTTP_CONV_FAILED = 1022175,
		ERROR_CODE_HTTP_CONV_REQD = 1022176,
		ERROR_CODE_HTTP_SSL_CACERT_BADFILE = 1022177,
		ERROR_CODE_HTTP_REMOTE_FILE_NOT_FOUND = 1022178,
		ERROR_CODE_HTTP_SSH = 1022179,
		ERROR_CODE_HTTP_SSL_SHUTDOWN_FAILED = 1022180,
		ERROR_CODE_HTTP_AGAIN = 1022181,
		ERROR_CODE_HTTP_SSL_CRL_BADFILE = 1022182,
		ERROR_CODE_HTTP_SSL_ISSUER_ERROR = 1022183,
		ERROR_CODE_HTTP_RTSP_CSEQ_ERROR = 1022185,
		ERROR_CODE_HTTP_RTSP_SESSION_ERROR = 1022186,
		ERROR_CODE_HTTP_CHUNK_FAILED = 1022188,
		ERROR_CODE_HTTP_NSSL_NO_CTX = 1022189,
		ERROR_CODE_SO_SELECT_ERROR = 1022211,
		ERROR_CODE_BAD_FORMAT_PARAMETER = 1022401,
		ERROR_CODE_BAD_FORMAT_REQUEST = 1022402,
		ERROR_CODE_REQUEST_PARAMETER_MISSING = 1022403,
		ERROR_CODE_WRONG_HTTP_METHOD = 1022404,
		ERROR_CODE_BAD_FORMAT_RESPONSE = 1022421,
		ERROR_CODE_RESPONSE_ITEM_MISSING = 1022422,
		ERROR_CODE_RESPONSE_TOO_LARGE = 1022423,
		ERROR_CODE_INVALID_PLATFORM_ID = 1022451,
		ERROR_CODE_UNAUTHORIZED_DEVIC = 1022452,
		ERROR_CODE_INVALID_SERIAL_ID = 1022453,
		ERROR_CODE_INVALID_MAC_ADDRESS = 1022454,
		ERROR_CODE_INVALID_REGION = 1022455,
		ERROR_CODE_INVALID_COUNTRY = 1022456,
		ERROR_CODE_INVALID_LANGUAGE = 1022457,
		ERROR_CODE_UNAUTHORIZED_CLIENT = 1022458,
		ERROR_CODE_DEVICE_ID_EMPTY = 1022459,
		ERROR_CODE_SERIAL_ID_EMPTY = 1022460,
		ERROR_CODE_PLATFORM_ID_EMPTY = 1022461,
		ERROR_CODE_DEVICE_MISMATCH = 1022501,
		ERROR_CODE_COUNTRY_MISMATCH = 1022502,
		ERROR_CODE_EULA_NOT_ACCEPTED = 1022503,
		ERROR_CODE_SYSTEM_UPDATE_REQUIRED = 1022511,
		ERROR_CODE_APPLICATION_UPDATE_REQUIRED = 1022512,
		ERROR_CODE_REQUEST_FORBIDDEN = 1022522,
		ERROR_CODE_PID_NOT_FOUND = 1022531,
		ERROR_CODE_NEX_ACCOUNT_NOT_FOUND = 1022532,
		ERROR_CODE_GENERATE_TOKEN_FAILURE = 1022533,
		ERROR_CODE_REQUEST_NOT_FOUND = 1022534,
		ERROR_CODE_MASTER_PIN_NOT_FOUND = 1022535,
		ERROR_CODE_MAIL_TEXT_NOT_FOUND = 1022536,
		ERROR_CODE_SEND_MAIL_FAILURE = 1022537,
		ERROR_CODE_INVALID_EULA_COUNTRY = 1022541,
		ERROR_CODE_INVALID_EULA_COUNTRY_AND_VERSION = 1022542,
		ERROR_CODE_EULA_NOT_FOUND = 1022543,
		ERROR_CODE_ACCOUNT_ID_ALREADY_EXISTS = 1022571,
		ERROR_CODE_ACCOUNT_ID_NOT_ACCEPTABLE = 1022572,
		ERROR_CODE_ACCOUNT_PASSWORD_NOT_ACCEPTABLE = 1022573,
		ERROR_CODE_MII_NAME_NOT_ACCEPTABLE = 1022574,
		ERROR_CODE_MAIL_ADDRESS_NOT_ACCEPTABLE = 1022575,
		ERROR_CODE_ACCOUNT_ID_FORMAT_INVALID = 1022576,
		ERROR_CODE_ACCOUNT_ID_PASSWORD_SAME = 1022577,
		ERROR_CODE_REACHED_ASSOCIATION_LIMIT = 1022591,
		ERROR_CODE_REACHED_REGISTRATION_LIMIT = 1022592,
		ERROR_CODE_COPPA_NOT_ACCEPTED = 1022593,
		ERROR_CODE_PARENTAL_CONTROLS_REQUIRED = 1022594,
		ERROR_CODE_MII_NOT_REGISTERD = 1022595,
		ERROR_CODE_DEVICE_EULA_COUNTRY_MISMATCH = 1022596,
		ERROR_CODE_WRONG_ACCOUNT_PASSWORD = 1022611,
		ERROR_CODE_WRONG_MAIL_ADDRESS = 1022612,
		ERROR_CODE_WRONG_ACCOUNT_PASSWORD_OR_MAIL_ADDRESS = 1022613,
		ERROR_CODE_WRONG_CONFIRMATION_CODE = 1022614,
		ERROR_CODE_WRONG_BIRTH_DATE_OR_MAIL_ADDRESS = 1022615,
		ERROR_CODE_WRONG_ACCOUNT_MAIL = 1022616,
		ERROR_CODE_ACCOUNT_ALREADY_DELETED = 1022631,
		ERROR_CODE_ACCOUNT_ID_CHANGED = 1022632,
		ERROR_CODE_AUTHENTICATION_LOCKED = 1022633,
		ERROR_CODE_ACCOUNT_TOKEN_EXPIRED = 1022641,
		ERROR_CODE_INVALID_ACCOUNT_TOKEN = 1022642,
		ERROR_CODE_CONFIRMATION_CODE_EXPIRED = 1022651,
		ERROR_CODE_MAIL_ADDRESS_NOT_VALIDATED = 1022661,
		ERROR_CODE_EXCESSIVE_MAIL_SEND_REQUEST = 1022662,
		ERROR_CODE_CREDIT_CARD_GENERAL_FAILURE = 1022671,
		ERROR_CODE_CREDIT_CARD_DECLINED = 1022672,
		ERROR_CODE_CREDIT_CARD_BLACKLISTED = 1022673,
		ERROR_CODE_INVALID_CREDIT_CARD_NUMBER = 1022674,
		ERROR_CODE_INVALID_CREDIT_CARD_DATE = 1022675,
		ERROR_CODE_INVALID_CREDIT_CARD_PIN = 1022676,
		ERROR_CODE_INVALID_POSTAL_CODE = 1022677,
		ERROR_CODE_INVALID_LOCATION = 1022678,
		ERROR_CODE_CREDIT_CARD_DATE_EXPIRED = 1022679,
		ERROR_CODE_CREDIT_CARD_NUMBER_WRONG = 1022680,
		ERROR_CODE_CREDIT_CARD_PIN_WRONG = 1022681,
		ERROR_CODE_BANNED_ACCOUNT_ALL = 1022802,
		ERROR_CODE_BANNED_ACCOUNT_IN_APPLICATION = 1022803,
		ERROR_CODE_BANNED_ACCOUNT_IN_NEX_SERVICE = 1022804,
		ERROR_CODE_BANNED_ACCOUNT_IN_INDEPENDENT_SERVICE = 1022805,
		ERROR_CODE_BANNED_DEVICE_ALL = 1022812,
		ERROR_CODE_BANNED_DEVICE_IN_APPLICATION = 1022813,
		ERROR_CODE_BANNED_DEVICE_IN_NEX_SERVICE = 1022814,
		ERROR_CODE_BANNED_DEVICE_IN_INDEPENDENT_SERVICE = 1022815,
		ERROR_CODE_UNDER_MAINTENANCE = 1022881,
		ERROR_CODE_SERVICE_CLOSED = 1022882,
		ERROR_CODE_NINTENDO_NETWORK_CLOSED = 1022883,
		ERROR_CODE_NOT_PROVIDED_COUNTRY = 1022884,
		ERROR_CODE_RESTRICTED_BY_AGE = 1022901,
		ERROR_CODE_INTERNAL_SERVER_ERROR = 1022931,

		FATAL,
	};


#endif//ERROR_CODES_H
