/*
 * Copyright (c) 2012 NINTENDO.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions, and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions, and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY NINTENDO AND ITS CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL NINTENDO OR CONTRIBUTORS BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef PLATFORMMEMORY_H
#define PLATFORMMEMORY_H

#include <cstring> // for size_t

namespace LibPlatform {
	class Memory {
	public:
		typedef void *HeapHandle;

		static void *Copy(void *destination, const void *source, size_t num);
		static void SetUsageHeapAllocators(void*(*allocFuncP)(int, unsigned int, signed int), void(*freeFuncP)(void *));

		static HeapHandle CreateExpHeap(void *start_address, unsigned size);
		static void *AllocFromExpHeap(HeapHandle heap_handle, unsigned size);
		static void *AllocFromExpHeapEx(HeapHandle heap_handle, unsigned size, signed alignment);
		static void *AllocFromDefaultHeap(unsigned size);
		static void *AllocFromDefaultHeapEx(unsigned size, signed alignment);
		static void* AllocFromUsageHeap(int usage, unsigned size, signed alignment);
		static void FreeToExpHeap(HeapHandle heap_handle, void *mem_block);
		static void FreeToDefaultHeap(void *mem_block);
		static void FreeToUsageHeap(void *mem_block);
		static void *DestroyExpHeap(HeapHandle heap_handle);
		static HeapHandle GetBaseHeapHandleArena1(void);
		static HeapHandle GetBaseHeapHandleArena2(void);
		static void DumpHeap(HeapHandle heap_handle);
		static signed GetHeapTotalSize(HeapHandle heap_handle);
		static signed GetHeapTotalUsableSize(HeapHandle heap_handle);
		static unsigned GetPPCIOBufferAlign(void);
	};
}

#endif//PLATFORMMEMORY_H
