/*
 * Copyright (c) 2012 NINTENDO.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions, and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions, and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY NINTENDO AND ITS CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL NINTENDO OR CONTRIBUTORS BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef PLATFORMSTATISTICS_H
#define PLATFORMSTATISTICS_H

#ifdef WIN32
	// Because Windows is so super-cool, it tries to define GetCurrentTime as GetTickCount.
	#ifdef GetCurrentTime
		#undef GetCurrentTime
	#endif
	#define GetCurrentTime GetCurrentTime
#endif

#include <map>
#include <string>

namespace LibPlatform {
	class PlatformStatistics {
		struct Timer {
			Timer(void) :
				started(false),
				start_time(0), 
				end_time(0), 
				avg_time(0),
				last_time(0) {}

			bool started;
			unsigned start_time;
			unsigned end_time;
			unsigned avg_time;
			unsigned last_time;
		};

		typedef bool Group;

	public:
		static PlatformStatistics *GetInstance(void);
		static void DestroyInstance(void);

		void StartTimer(std::string timer_name, std::string group_name);
		void StopTimer(std::string timer_name, std::string group_name);
		unsigned GetAverageTime(std::string timer_name);
		unsigned GetLastTime(std::string timer_name);
		unsigned GetCurrentTime(std::string timer_name);
		void EnableGroup(std::string switch_name);
		void DisableGroup(std::string switch_name);

	private:
		PlatformStatistics(void);
		~PlatformStatistics(void);

		std::map<std::string, Timer> timers;
		std::map<std::string, Group> groups;
	};
}

#endif//PLATFORMSTATISTICS_H
