/*
 * Copyright (c) 2012 NINTENDO.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions, and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions, and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY NINTENDO AND ITS CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL NINTENDO OR CONTRIBUTORS BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef __WIIUEVENTS_H_INCLUDED
#define __WIIUEVENTS_H_INCLUDED

#include <inttypes.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Events
 */

enum {
	WIIUEVENTS_BUTTON_NONE,
	WIIUEVENTS_LEFT,
	WIIUEVENTS_MIDDLE,
	WIIUEVENTS_RIGHT,
};

typedef struct {
	int dummy; // This is here because the compiler doesn't like empty structures.  It can be removed when we flush this out
} WiiUEventExposeEvent;

typedef struct {
	int dummy; // This is here because the compiler doesn't like empty structures.  It can be removed when we flush this out
} WiiUEventResizeEvent;

typedef struct {
	int dummy; // This is here because the compiler doesn't like empty structures.  It can be removed when we flush this out
} WiiUEventQuitEvent;

typedef struct {
	int dummy; // This is here because the compiler doesn't like empty structures.  It can be removed when we flush this out
} WiiUEventUserEvent;

typedef struct {
	int state;
	uint8_t scancode;                 /**< hardware specific scancode */
	int 	sym;                     /**< SDL virtual keysym */
	int 	mod;                     /**< current key modifiers */
	uint16_t unicode;                 /**< translated character */
} WiiUEventKeyboardEvent;

typedef struct {
	int x;
	int y;
	int button;
	int state;
} WiiUEventMouseEvent;

typedef struct {
	int x;
	int y;
	int button;
	int state;
} WiiUEventWheelMouseEvent;

typedef struct {
	int dummy; // This is here because the compiler doesn't like empty structures.  It can be removed when we flush this out
} WiiUEventCursor;

typedef struct {
	int dummy; // This is here because the compiler doesn't like empty structures.  It can be removed when we flush this out
} WiiUEventWidget;

typedef struct {
	int x;
	int y;
} WiiUEventPoint;

typedef struct {
	int x;
	int y;
	int x2;
	int y2;
	int w;
	int h;
} WiiUEventRect;

typedef struct {
	int (*func)(void *);
	void *data;
	int msec;
} WiiUEventTimer;

enum {
	WIIUEVENT_CALLBACK_CANCEL = 1,
};

// function prototypes
void 		wiiuevent_check_timers();
int 		wiiuevent_get_time();
WiiUEventTimer * 	wiiuevent_timer_add(int t, int (*timeoutfunc)(void *), int m);
int 		wiiuevent_timer_remove(WiiUEventTimer *);

#ifdef __cplusplus
}
#endif

#endif

