/*
 * Copyright (c) 2012 NINTENDO.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions, and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions, and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY NINTENDO AND ITS CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL NINTENDO OR CONTRIBUTORS BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __WKSUP_MEMORY_H__
#define __WKSUP_MEMORY_H__

#ifdef __cplusplus
extern "C"
{
#endif

enum WKSUP_HEAPS
{
	WKSUP_DEFAULT_HEAP = -1,
	WKSUP_TEXTURE_HEAP,
	WKSUP_DECODE_HEAP,
	WKSUP_CANVAS_HEAP,
	WKSUP_JSC_HEAP,
	WKSUP_JSC_REGISTER_HEAP,
	WKSUP_NUM_HEAPS
};

struct WKSUPmemInfo
{
	unsigned int	mTotal;
	unsigned int	mAllocated;
	unsigned int	mAvailable;
	unsigned int	mNumCurrentAllocs;
	// separate heap stuff
	unsigned int	mHeap1Total;
	unsigned int	mHeap1Free;
	unsigned int	mHeap2Total;
	unsigned int	mHeap2Free;
	unsigned int	mHeap3Total;
	unsigned int	mHeap3Free;
	// new heaps for canvas and jsc heap
	unsigned int	mHeap4Total;
	unsigned int	mHeap4Free;
	unsigned int	mHeap5Total;
	unsigned int	mHeap5Free;
	unsigned int	mHeap6Total;
	unsigned int	mHeap6Free;
};

void wksupMemoryInit(void);	// basically initialize the mutex
void wksupMemorySetHeapHandle(int index, void* heapHandle, void *startP, int size);
void wksupMemorySetInfoCallback(void (*InfoFN)(WKSUPmemInfo *pInfo));
void wksupMemoryGetInfo(WKSUPmemInfo *pInfo);

void* wksupMEMAllocFromHeap(int index, unsigned long size, int alignment=8);
void wksupMEMFreeToHeap(int index, void *dataP);	// if -1, use getHeapIndex
int wksupMEMGetHeapIndex(void *dataP);	// based on dataP, get the index

// use the pool IDX, not the wksup index
void wksupMEMFreeToHeapPoolIdx(int index, void *dataP);

#ifdef __cplusplus
}
#endif

#endif /// __WKSUP_MEMORY_H__

